@@ -27,14 +27,11 @@
  */
 
 #include <config.h>
-
-#include <string.h>
-#include <gnome.h>
-
 #include "nautilus-navigation-bar.h"
 
+#include <eel/eel-gtk-macros.h>
 #include <gtk/gtksignal.h>
-#include <libnautilus-extensions/nautilus-gtk-macros.h>
+#include <string.h>
 
 enum {
 	ACTIVATE,
@@ -43,49 +40,49 @@ enum {
 };
 static guint signals[LAST_SIGNAL];
 
-static void nautilus_navigation_bar_initialize_class (NautilusNavigationBarClass *class);
-static void nautilus_navigation_bar_initialize       (NautilusNavigationBar      *bar);
+static void nautilus_navigation_bar_class_init (NautilusNavigationBarClass *class);
+static void nautilus_navigation_bar_init       (NautilusNavigationBar      *bar);
 
-NAUTILUS_DEFINE_CLASS_BOILERPLATE (NautilusNavigationBar, nautilus_navigation_bar, NAUTILUS_TYPE_GENEROUS_BIN)
+EEL_CLASS_BOILERPLATE (NautilusNavigationBar, nautilus_navigation_bar, EEL_TYPE_GENEROUS_BIN)
 
-NAUTILUS_IMPLEMENT_MUST_OVERRIDE_SIGNAL (nautilus_navigation_bar, get_location)
-NAUTILUS_IMPLEMENT_MUST_OVERRIDE_SIGNAL (nautilus_navigation_bar, set_location)
+EEL_IMPLEMENT_MUST_OVERRIDE_SIGNAL (nautilus_navigation_bar, get_location)
+EEL_IMPLEMENT_MUST_OVERRIDE_SIGNAL (nautilus_navigation_bar, set_location)
 
 static void
-nautilus_navigation_bar_initialize_class (NautilusNavigationBarClass *klass)
+nautilus_navigation_bar_class_init (NautilusNavigationBarClass *klass)
 {
 	GtkObjectClass *object_class;
 
 	object_class = GTK_OBJECT_CLASS (klass);
 	
-	signals[ACTIVATE] = gtk_signal_new
+	signals[ACTIVATE] = g_signal_new
 		("activate",
-		 GTK_RUN_LAST,
-		 object_class->type,
-		 GTK_SIGNAL_OFFSET (NautilusNavigationBarClass,
+		 G_TYPE_FROM_CLASS (object_class),
+		 G_SIGNAL_RUN_LAST,
+		 G_STRUCT_OFFSET (NautilusNavigationBarClass,
 				    activate),
-		 gtk_marshal_NONE__NONE,
-		 GTK_TYPE_NONE, 0);
+		 NULL, NULL,
+		 g_cclosure_marshal_VOID__VOID,
+		 G_TYPE_NONE, 0);
 
-	signals[LOCATION_CHANGED] = gtk_signal_new
+	signals[LOCATION_CHANGED] = g_signal_new
 		("location_changed",
-		 GTK_RUN_LAST,
-		 object_class->type,
-		 GTK_SIGNAL_OFFSET (NautilusNavigationBarClass,
+		 G_TYPE_FROM_CLASS (object_class),
+		 G_SIGNAL_RUN_LAST,
+		 G_STRUCT_OFFSET (NautilusNavigationBarClass,
 				    location_changed),
-		 gtk_marshal_NONE__STRING,
-		 GTK_TYPE_NONE, 1, GTK_TYPE_STRING);
-
-	gtk_object_class_add_signals (object_class, signals, LAST_SIGNAL);
+		 NULL, NULL,
+		 g_cclosure_marshal_VOID__STRING,
+		 G_TYPE_NONE, 1, G_TYPE_STRING);
 
 	klass->activate = NULL;
 
-	NAUTILUS_ASSIGN_MUST_OVERRIDE_SIGNAL (klass, nautilus_navigation_bar, get_location);
-	NAUTILUS_ASSIGN_MUST_OVERRIDE_SIGNAL (klass, nautilus_navigation_bar, set_location);
+	EEL_ASSIGN_MUST_OVERRIDE_SIGNAL (klass, nautilus_navigation_bar, get_location);
+	EEL_ASSIGN_MUST_OVERRIDE_SIGNAL (klass, nautilus_navigation_bar, set_location);
 }
 
 static void
-nautilus_navigation_bar_initialize (NautilusNavigationBar *bar)
+nautilus_navigation_bar_init (NautilusNavigationBar *bar)
 {
 }
 
@@ -101,7 +98,7 @@ nautilus_navigation_bar_activate (NautilusNavigationBar *bar)
 {
 	g_return_if_fail (NAUTILUS_IS_NAVIGATION_BAR (bar));
 
-	gtk_signal_emit (GTK_OBJECT (bar), signals[ACTIVATE]);
+	g_signal_emit (bar, signals[ACTIVATE], 0);
 }
 
 /**
@@ -117,7 +114,7 @@ nautilus_navigation_bar_get_location (NautilusNavigationBar *bar)
 {
 	g_return_val_if_fail (NAUTILUS_IS_NAVIGATION_BAR (bar), NULL);
 
-	return NAUTILUS_CALL_METHOD_WITH_RETURN_VALUE
+	return EEL_CALL_METHOD_WITH_RETURN_VALUE
 		(NAUTILUS_NAVIGATION_BAR_CLASS, bar,
 		 get_location, (bar));
 }
@@ -136,7 +133,7 @@ nautilus_navigation_bar_set_location (NautilusNavigationBar *bar,
 {
 	g_return_if_fail (NAUTILUS_IS_NAVIGATION_BAR (bar));
 
-	NAUTILUS_CALL_METHOD (NAUTILUS_NAVIGATION_BAR_CLASS, bar,
+	EEL_CALL_METHOD (NAUTILUS_NAVIGATION_BAR_CLASS, bar,
 			      set_location, (bar, location));
 }
 
@@ -148,8 +145,8 @@ nautilus_navigation_bar_location_changed (NautilusNavigationBar *bar)
 	g_return_if_fail (NAUTILUS_IS_NAVIGATION_BAR (bar));
 
 	location = nautilus_navigation_bar_get_location (bar);
-	gtk_signal_emit (GTK_OBJECT (bar),
-			 signals[LOCATION_CHANGED],
+	g_signal_emit (bar,
+			 signals[LOCATION_CHANGED], 0,
 			 location);
 	g_free (location);
 }
